;; Generated package description from tomelr.el  -*- no-byte-compile: t -*-
(define-package "tomelr" "0.2.2.0.20220503.143428" "Convert S-expressions to TOML" '((emacs "26.3")) :commit "4e2edfe073d2a057a37b159d4e67282aa132f596" :authors '(("Kaushal Modi" . "kaushal.modi@gmail.com")) :maintainer '("Kaushal Modi" . "kaushal.modi@gmail.com") :keywords '("data" "tools" "toml" "serialization" "config") :url "https://github.com/kaushalmodi/tomelr/")
